@@ -1,4 +1,4 @@
-# Copyright 2017 Descartes Labs.
+# Copyright 2018 Descartes Labs.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,15 +13,18 @@
 # limitations under the License.
 
 # flake8: noqa
+from .client.auth import Auth
+from .client import services
+from .client.services import *
+
+try:
+    from . import scenes
+except ImportError:
+    pass
 
-__version__ = "0.4.7"
-from .auth import Auth
 descartes_auth = Auth.from_environment_or_token_json()
+metadata = Metadata(auth=descartes_auth)
+places = Places(auth=descartes_auth)
+raster = Raster(auth=descartes_auth)
 
-from .services.metadata import Metadata
-from .services.places import Places
-from .services.raster import Raster
-
-metadata = Metadata()
-places = Places()
-raster = Raster()
+__all__ = ["descartes_auth", "metadata", "places", "raster", "Auth"] + services.__all__
